'' =================================================================================================
''
''   File....... jm_max31855__demo.spin 
''   Purpose.... 
''   Author..... Jon "JonnyMac" McPhalen
''   E-mail.....
''   Started.... 
''   Updated.... 27 AUG 2014
''
'' =================================================================================================


con  { speed / timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal
' _xinfreq = 6_250_000                                          ' use 6.25MHz crystal

  CLK_FREQ = ((_clkmode - xtal1) >> 6) * _xinfreq
  MS_001   = CLK_FREQ / 1_000
  US_001   = CLK_FREQ / 1_000_000


con { io pins }

  RX1      = 31                                                 ' programming / terminal
  TX1      = 30
  
  SDA      = 29                                                 ' eeprom / i2c
  SCL      = 28

  SPI_MISO =  3                                                 ' shared spi buss
  SPI_MOSI =  2
  SPI_CLK  =  1
    
  TCI_CS   =  0


con 

  #(-1), IS_ON, IS_OFF
  

con { pst formatting }

   #1, HOME, GOTOXY, #8, BKSP, TAB, LF, CLREOL, CLRDN, CR
  #14, GOTOX, GOTOY, CLS


obj

  tci  : "jm_max31855"      
  term : "fullduplexserial64"
 

var


pub main | t, work

  high(TCI_CS)                                                  ' setup CS, deactivate TCI
  tci.start(-33, SPI_CLK, SPI_MISO, -1)                         ' start TCI; external chip select, no lock 
  term.start(RX1, TX1, %0000, 115_200)                          ' start terminal
  pause(1)

  term.str(string(CLS, "MAX31855 SPI/XCS Demo"))

  t := cnt
  repeat
    term.tx(HOME)
    term.tx(LF)
    term.tx(LF)
    term.str(string("Faults.... "))
    low(TCI_CS)                                                 ' activate MAX31855
    work := tci.read_faults(true)                               ' re-scan
    high(TCI_CS)                                                ' de-activate
    term.bin(work, 3)
    if (work)
      term.str(string(" -> "))  
      term.str(tci.fault_str(work))
    term.tx(CLREOL)
    term.tx(CR)

    term.str(string("TC Temp... "))
    low(TCI_CS)
    term.dec(tci.read_tc(true))
    high(TCI_CS)    
    term.tx(CLREOL)
    term.tx(CR)

    term.str(string("CJ Temp... "))
    low(TCI_CS)
    term.dec(tci.read_cj(true))
    high(TCI_CS)
    term.tx(CLREOL)
    term.tx(CR)

    waitcnt(t += constant(100 * MS_001))


con

  { ------------- }
  {  B A S I C S  }
  { ------------- }


pub pause(ms) | t

'' Delay program in milliseconds

  if (ms < 1)                                                   ' delay must be > 0
    return
  else
    t := cnt - 1776                                             ' sync with system counter
    repeat ms                                                   ' run delay
      waitcnt(t += MS_001)
    

pub high(pin)

'' Makes pin output and high

  outa[pin] := 1
  dira[pin] := 1


pub low(pin)

'' Makes pin output and low

  outa[pin] := 0
  dira[pin] := 1


pub toggle(pin)

'' Toggles pin state

  !outa[pin]
  dira[pin] := 1


pub input(pin)

'' Makes pin input and returns current state

  dira[pin] := 0

  return ina[pin]


dat { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}